@@ -75,7 +75,8 @@ if ($do==1) {
       if ($uname_all=~/x86_64/) {
          foreach my $package ('libxml2','libxml2-devel','libtool',
                'autoconf','autobuild','automake','pkg-config',
-               'libuuid-devel','wget','git') {
+               'libuuid-devel','wget','git','httpd',
+               'httpd-mod_ssl','httpd-tools') {
             unless (-1<index $cygcheck, "$package ") {
                $need_packages{$package}='';
             }
@@ -83,28 +84,42 @@ if ($do==1) {
       } else {
          foreach my $package ('libxml2','libxml2-devel','libtool',
                'autoconf','autobuild','automake','pkg-config',
-               'libuuid-devel','wget','git') {
+               'libuuid-devel','wget','git','httpd','httpd-mod_ssl',
+               'httpd-tools') {
             unless (-1<index $cygcheck, "$package ") {
                $need_packages{$package}='';
             }
          }
       }
+      # http://www.fjakkarin.com/2015/11/cygwin-cygserver-and-apache-httpd/
+      ($stdout,$stderr)=$handle->cmd(
+         "wget --random-wait --progress=dot ".
+         "https://github.com/transcode-open/apt-cyg/archive/master.zip",
+         '__display__');
+      ($stdout,$stderr)=$handle->cmd("unzip master.zip",'__display__');
+      ($stdout,$stderr)=$handle->cmd("rm -rvf master.zip",'__display__');
+      ($stdout,$stderr)=$handle->cmd("mv apt-cyg-master/apt-cyg /usr/bin");
+      ($stdout,$stderr)=$handle->cmd("chmod -v 755 /usr/bin/apt-cyg",
+         '__display__');
+      ($stdout,$stderr)=$handle->cmd("rm -rvf apt-cyg-master",'__display__');
       my $packs='';$|=1;
       foreach my $pack (sort keys %need_packages) {
-         $packs.="$pack ";
+         ($stdout,$stderr)=$handle->cmd("apt-cyg install $pack",
+            '__display__');
+         #$packs.="$pack ";
       }
-      if ($packs) {
-         print "\n\n   Fatal Error!: The following Cygwin",
-               "\n                 packages are missing from",
-               "\n                 your installation:",
-               "\n\n   $packs",
-               "\n\n   Please report any bugs and send any",
-               "\n   questions, thoughts or feedback to:",
-               "\n\n      Brian.Kelly\@FullAuto.com.",
-               "\n\n";
-         &Net::FullAuto::FA_Core::cleanup;
-      }
-      print "\nInstalling Microsoft IIS Web Server . . .\n\n";
+      #if ($packs) {
+      #   print "\n\n   Fatal Error!: The following Cygwin",
+      #         "\n                 packages are missing from",
+      #         "\n                 your installation:",
+      #         "\n\n   $packs",
+      #         "\n\n   Please report any bugs and send any",
+      #         "\n   questions, thoughts or feedback to:",
+      #         "\n\n      Brian.Kelly\@FullAuto.com.",
+      #         "\n\n";
+      #   &Net::FullAuto::FA_Core::cleanup;
+      #}
+      #print "\nInstalling Microsoft IIS Web Server . . .\n\n";
       # http://www.iis.net/learn/install/installing-iis-85/
       #      installing-iis-85-on-windows-server-2012-r2
       # https://technet.microsoft.com/en-us/library/hh831475.aspx
@@ -142,54 +157,54 @@ if ($do==1) {
       #   "/featureName:IIS-ApplicationInit /featureName:IIS-WebSockets ".
       #   "/featureName:IIS-CertProvider /featureName:IIS-ManagementConsole ".
       #   "/featureName:IIS-LegacySnapIn",'__display__');
-      ($stdout,$stderr)=$handle->cmd("DISM.EXE /online /enable-feature ".
-         "/featureName:IIS-WebServerRole /featureName:IIS-WebServer ".
-         "/featureName:IIS-CommonHttpFeatures /featureName:IIS-StaticContent ".
-         "/featureName:IIS-DefaultDocument /featureName:IIS-DirectoryBrowsing ".
-         "/featureName:IIS-HttpErrors /featureName:IIS-HealthAndDiagnostics ".
-         "/featureName:IIS-HttpLogging /featureName:IIS-Performance ".
-         "/featureName:IIS-HttpCompressionStatic /featureName:IIS-Security ".
-         "/featureName:IIS-RequestFiltering /featureName:IIS-CGI ".
-         "/featureName:IIS-WebServerManagementTools ".
-         "/featureName:IIS-ManagementConsole",'__display__');
-      my $appcmd="$ENV{WINDIR}/SYSTEM32/inetsrv";
-      ($appcmd,$stderr)=$handle->cmd("cygpath -u $appcmd");
-      my $cyglocb=$handle->cmd("cygpath -w /");
-      my $cyglocw=$handle->cmd("cygpath -w ~");
-      my $cyglocwf="$cyglocw\\FullAutoAPI";
-      $cyglocw=~s/\\/\\\\/g;
-      $cyglocwf=~s/\\/\\\\/g;
-      ($stdout,$stderr)=$handle->cwd($appcmd);
-      ($stdout,$stderr)=$handle->cmd("pwd",'__display__');
-      my $sleep=0;
-      while (1==1) {
-        my $ls_output=$handle->cmd("ls -1");
-        last if -1<index $ls_output,'appcmd.exe';
-        sleep 2;
-        last if $sleep++>300;
-      }
-      sleep 5;
-      ($stdout,$stderr)=$handle->cmd("./appcmd add site /name:FullAutoAPI ".
-         "/id:2 /physicalPath:$cyglocwf\\root /bindings:http/*:4000",
-         '__display__');
-      sleep 2;
-      ($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
-         "system.webServer/fastCgi /+[\"fullpath=\'$cyglocb\\script\\".
-         "CGI_script.bat\',arguments=\'$cyglocwf\\script\\".
-         "fullautoapi_fastcgi.pl -e\',maxInstances=\'4\',".
-         "idleTimeout=\'300\',activityTimeout=\'30\',requestTimeout='\90\',".
-         "instanceMaxRequests=\'1000\',protocol=\'NamedPipe\',".
-         "flushNamedPipe=\'False\']\" /commit:apphost",'__display__');
-      sleep 2;
-      ($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
-         "system.webServer/handlers /+\"[name=\'FullAutoAPI\',".
-         "path=\'*\',verb=\'GET,HEAD,POST\',modules=".
-         "\'FastCgiModule\',scriptProcessor=\'$cyglocb\\script\\".
-         "CGI_Script.bat|$cyglocwf\\script\\fullautoapi_fastcgi.pl -e\',".
-         "resourceType=\'Unspecified\',requireAccess=\'Script\']\" ".
-         "/commit:apphost",'__display__');
-      ($stdout,$stderr)=$handle->cwd("FullAutoAPI/script");
-      ($stdout,$stderr)=$handle->cmd("touch CGI_Script.bat");
+      #($stdout,$stderr)=$handle->cmd("DISM.EXE /online /enable-feature ".
+      #   "/featureName:IIS-WebServerRole /featureName:IIS-WebServer ".
+      #   "/featureName:IIS-CommonHttpFeatures /featureName:IIS-StaticContent ".
+      #   "/featureName:IIS-DefaultDocument /featureName:IIS-DirectoryBrowsing ".
+      #   "/featureName:IIS-HttpErrors /featureName:IIS-HealthAndDiagnostics ".
+      #   "/featureName:IIS-HttpLogging /featureName:IIS-Performance ".
+      #   "/featureName:IIS-HttpCompressionStatic /featureName:IIS-Security ".
+      #   "/featureName:IIS-RequestFiltering /featureName:IIS-CGI ".
+      #   "/featureName:IIS-WebServerManagementTools ".
+      #   "/featureName:IIS-ManagementConsole",'__display__');
+      #my $appcmd="$ENV{WINDIR}/SYSTEM32/inetsrv";
+      #($appcmd,$stderr)=$handle->cmd("cygpath -u $appcmd");
+      #my $cyglocb=$handle->cmd("cygpath -w /");
+      #my $cyglocw=$handle->cmd("cygpath -w ~");
+      #my $cyglocwf="$cyglocw\\FullAutoAPI";
+      #$cyglocw=~s/\\/\\\\/g;
+      #$cyglocwf=~s/\\/\\\\/g;
+      #($stdout,$stderr)=$handle->cwd($appcmd);
+      #($stdout,$stderr)=$handle->cmd("pwd",'__display__');
+      #my $sleep=0;
+      #while (1==1) {
+      #  my $ls_output=$handle->cmd("ls -1");
+      #  last if -1<index $ls_output,'appcmd.exe';
+      #  sleep 2;
+      #  last if $sleep++>300;
+      #}
+      #sleep 5;
+      #($stdout,$stderr)=$handle->cmd("./appcmd add site /name:FullAutoAPI ".
+      #   "/id:2 /physicalPath:$cyglocwf\\root /bindings:http/*:4000",
+      #   '__display__');
+      #sleep 2;
+      #($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
+      #   "system.webServer/fastCgi /+[\"fullpath=\'$cyglocb\\script\\".
+      #   "CGI_script.bat\',arguments=\'$cyglocwf\\script\\".
+      #   "fullautoapi_fastcgi.pl -e\',maxInstances=\'4\',".
+      #   "idleTimeout=\'300\',activityTimeout=\'30\',requestTimeout='\90\',".
+      #   "instanceMaxRequests=\'1000\',protocol=\'NamedPipe\',".
+      #   "flushNamedPipe=\'False\']\" /commit:apphost",'__display__');
+      #sleep 2;
+      #($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
+      #   "system.webServer/handlers /+\"[name=\'FullAutoAPI\',".
+      #   "path=\'*\',verb=\'GET,HEAD,POST\',modules=".
+      #   "\'FastCgiModule\',scriptProcessor=\'$cyglocb\\script\\".
+      #   "CGI_Script.bat|$cyglocwf\\script\\fullautoapi_fastcgi.pl -e\',".
+      #   "resourceType=\'Unspecified\',requireAccess=\'Script\']\" ".
+      #   "/commit:apphost",'__display__');
+      #($stdout,$stderr)=$handle->cwd("FullAutoAPI/script");
+      #($stdout,$stderr)=$handle->cmd("touch CGI_Script.bat");
       #
       # echo-ing/streaming files over ssh can be tricky. Use echo -e
       #          and replace these characters with thier HEX
@@ -201,12 +216,12 @@ if ($do==1) {
       #          "  -   \\x22     \  -  \\x5C
       #          $  -   \\x24
       #
-      $cyglocb=~s/\\/\\x5C/g;
-      my $content=<<END;
-$cyglocb\\x5Cbin\\x5Cbash -lc \\x22/bin/perl \\x251 \\x252\\x22
-END
-      ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > CGI_Script.bat");
-      ($stdout,$stderr)=$handle->cwd("~");
+      #$cyglocb=~s/\\/\\x5C/g;
+      #my $content=<<END;
+#$cyglocb\\x5Cbin\\x5Cbash -lc \\x22/bin/perl \\x251 \\x252\\x22
+#END
+      #($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > CGI_Script.bat");
+      #($stdout,$stderr)=$handle->cwd("~");
       #($stdout,$stderr)=$handle->cmd("iisreset /start",'__display__');
    }
    ###############
@@ -395,6 +410,99 @@ if ($do==1) {
    ($stdout,$stderr)=$handle->cwd("..");
 }
 $do=0;
+if ($do==1) { # NGINX
+   # https://nealpoole.com/blog/2011/04/setting-up-php-fastcgi-and-nginx
+   #    -dont-trust-the-tutorials-check-your-configuration/
+   # https://www.digitalocean.com/community/tutorials/
+   #    understanding-and-implementing-fastcgi-proxying-in-nginx
+   # http://dev.soup.io/post/1622791/I-managed-to-get-nginx-running-on
+   # http://search.cpan.org/dist/Catalyst-Manual-5.9002/lib/Catalyst/
+   #    Manual/Deployment/nginx/FastCGI.pod
+   my $nginx='nginx-1.9.13';
+   ($stdout,$stderr)=$handle->cmd("wget --random-wait --progress=dot ".
+      "http://nginx.org/download/$nginx.tar.gz",'__display__');
+   ($stdout,$stderr)=$handle->cmd("tar xvf $nginx.tar.gz",'__display__');
+   ($stdout,$stderr)=$handle->cwd($nginx);
+   ($stdout,$stderr)=$handle->cmd("mkdir -vp objs/lib",'__display__');
+   ($stdout,$stderr)=$handle->cwd("objs/lib");
+   my $pcre='pcre-8.38';
+   my $checksum='';
+   ($stdout,$stderr)=$handle->cmd("wget --random-wait --progress=dot ".
+      "ftp://ftp.csx.cam.ac.uk/pub/software/".
+      "programming/pcre/$pcre.tar.gz",'__display__');
+   ($stdout,$stderr)=$handle->cmd("tar xvf $pcre.tar.gz",'__display__');
+   my $zlib='zlib-1.2.8';
+   ($stdout,$stderr)=$handle->cmd("wget --random-wait --progress=dot ".
+      "http://zlib.net/$zlib.tar.gz",'__display__');
+   my $checksum='44d667c142d7cda120332623eab69f40';
+   ($stdout,$stderr)=$handle->cmd("md5sum -c - <<<\"$checksum $zlib.tar.gz\"",
+      '__display__');
+   unless ($stderr) {
+      print(qq{ + CHECKSUM Test for $zlib *PASSED* \n});
+   } else {
+      ($stdout,$stderr)=$handle->cmd("rm -rvf $zlib.tar.gz",'__display__');
+      my $dc=1;
+      print "FATAL ERROR! : CHECKSUM Test for $zlib.tar.gz *FAILED* ",
+            "after $dc attempts\n";
+      &Net::FullAuto::FA_Core::cleanup;
+   }
+   ($stdout,$stderr)=$handle->cmd("tar xvf $zlib.tar.gz",'__display__');
+   my $ossl='openssl-1.0.2g';
+   $checksum='36af23887402a5ea4ebef91df8e61654906f58f2';
+   ($stdout,$stderr)=$handle->cmd(
+      "https://www.openssl.org/source/$ossl.tar.gz",
+      '__display__');
+   ($stdout,$stderr)=$handle->cmd("shasum -c - <<<\"$checksum $ossl.tar.gz\"",
+      '__display__');
+   unless ($stderr) {
+      print(qq{ + CHECKSUM Test for $ossl *PASSED* \n});
+   } else {
+      ($stdout,$stderr)=$handle->cmd("rm -rvf $ossl.tar.gz",'__display__');
+      my $dc=1;
+      print "FATAL ERROR! : CHECKSUM Test for $ossl.tar.gz *FAILED* ",
+            "after $dc attempts\n";
+      &Net::FullAuto::FA_Core::cleanup;
+   }
+   ($stdout,$stderr)=$handle->cmd("tar xvf $ossl.tar.gz",'__display__');
+   ($stdout,$stderr)=$handle->cwd("../..");
+   my $make_nginx='./configure --sbin-path=/usr/local/nginx/nginx '.
+                  '--conf-path=/usr/local/nginx/nginx.conf '.
+                  '--pid-path=/usr/local/nginx/nginx.pid '.
+                  "--with-http_ssl_module --with-pcre=objs/lib/$pcre ".
+                  '--with-zlib=objs/lib/$zlib';
+   ($stdout,$stderr)=$handle->cmd($make_nginx,'__display__');
+   ($stdout,$stderr)=$handle->cmd("make install",'__display__');
+   ($stdout,$stderr)=$handle->cmd("sed -i 's/1024/64/' ".
+      "/usr/local/nginx/nginx.conf");
+   $ad="%NL%".
+       "%NL%            include fastcgi_params; # We'll discuss this later".
+       "%NL%            fastcgi_pass  localhost:3003;%NL%%NL%";
+   ($stdout,$stderr)=$handle->cmd("sed -i \'/location \/ \{/a$ad\' ".
+      "/usr/local/nginx/nginx.conf");
+   $ad='%NL%'.
+       '%NL%        location /static {'.
+       '%NL%            root /home/Administrator/FullAutoAPI/root;'.
+       '%NL%        }%NL%%NL%';
+   ($stdout,$stderr)=$handle->cmd(
+      "${sudo}sed -i \'/404/a$ad\' /usr/local/nginx/nginx.conf");
+   ($stdout,$stderr)=$handle->cmd(
+       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
+       "/usr/local/nginx/nginx.conf");
+   ($stdout,$stderr)=$handle->cmd("sed -i 's/SCRIPT_NAME/PATH_INFO/' ".
+      "/usr/local/nginx/fastcgi_params");
+   $ad='# Catalyst requires setting PATH_INFO (instead of SCRIPT_NAME)'.
+       ' to \$fastcgi_script_name';
+   ($stdout,$stderr)=$handle->cmd(
+      "${sudo}sed -i \'/PATH_INFO/i$ad\' /usr/local/nginx/fastcgi_params");
+   $ad='fastcgi_param  SCRIPT_NAME        /;';
+   ($stdout,$stderr)=$handle->cmd(
+      "${sudo}sed -i \'/PATH_INFO/a$ad\' /usr/local/nginx/fastcgi_params");
+   ($stdout,$stderr)=$handle->cmd(
+       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
+       "/usr/local/nginx/fastcgi_params");
+   ($stdout,$stderr)=$handle->cmd('/usr/local/nginx/nginx');
+}
+$do=0;
 if ($do==1) {
    my $go=$1;my $gosha1=$2;
    ($stdout,$stderr)=$handle->cmd("wget -qO- https://golang.org/dl");
@@ -2148,16 +2256,16 @@ END
        "}%NL%";
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i \'/use Catalyst::ScriptRunner/i$ad\' ".
-      "./script/fullautoapi_server.pl");
+      "./script/fullautoapi_fastcgi.pl");
    ($stdout,$stderr)=$handle->cmd( # bash shell specific
       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
-      "./script/fullautoapi_server.pl");
+      "./script/fullautoapi_fastcgi.pl");
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" ".
-      "./script/fullautoapi_server.pl");
+      "./script/fullautoapi_fastcgi.pl");
    ($stdout,$stderr)=$handle->cmd("${sudo}ldconfig");
 print "GOING TO START WEB SERVER\n";
    $handle->{_cmd_handle}->print(
-      "${sudo}script/fullautoapi_server.pl -p 3001 &");
+      "${sudo}script/fullautoapi_fastcgi.pl -p 3001 &");
    $prompt=substr($handle->{_cmd_handle}->prompt(),1,-1);
    while (1) {
       my $output.=Net::FullAuto::FA_Core::fetch($handle);
